==> lpc55-pac-0.4.0.crate: lpc55-pac-0.4.0/src/powerquad/inbbase.rs <==
#[doc = "Register `INBBASE` reader"]
pub struct R(crate::R<INBBASE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<INBBASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<INBBASE_SPEC>> for R {
    fn from(reader: crate::R<INBBASE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `INBBASE` writer"]
pub struct W(crate::W<INBBASE_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<INBBASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<INBBASE_SPEC>> for W {
    fn from(writer: crate::W<INBBASE_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `inbbase` reader - Base address register for the input B region"]
pub struct INBBASE_R(crate::FieldReader<u32, u32>);
impl INBBASE_R {
    pub(crate) fn new(bits: u32) -> Self {
        INBBASE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for INBBASE_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `inbbase` writer - Base address register for the input B region"]
pub struct INBBASE_W<'a> {
    w: &'a mut W,
}
impl<'a> INBBASE_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Base address register for the input B region"]
    #[inline(always)]
    pub fn inbbase(&self) -> INBBASE_R {
        INBBASE_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Base address register for the input B region"]
    #[inline(always)]
    pub fn inbbase(&mut self) -> INBBASE_W {
        INBBASE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Base address register for input B region\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [inbbase](index.html) module"]
pub struct INBBASE_SPEC;
impl crate::RegisterSpec for INBBASE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [inbbase::R](R) reader structure"]
impl crate::Readable for INBBASE_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [inbbase::W](W) writer structure"]
impl crate::Writable for INBBASE_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets INBBASE to value 0"]
impl crate::Resettable for INBBASE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> lpc55-pac-0.4.1.crate: lpc55-pac-0.4.1/src/powerquad/inbbase.rs <==
#[doc = "Register `INBBASE` reader"]
pub struct R(crate::R<INBBASE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<INBBASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<INBBASE_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<INBBASE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `INBBASE` writer"]
pub struct W(crate::W<INBBASE_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<INBBASE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<INBBASE_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<INBBASE_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `inbbase` reader - Base address register for the input B region"]
pub struct INBBASE_R(crate::FieldReader<u32, u32>);
impl INBBASE_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        INBBASE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for INBBASE_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `inbbase` writer - Base address register for the input B region"]
pub struct INBBASE_W<'a> {
    w: &'a mut W,
}
impl<'a> INBBASE_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Base address register for the input B region"]
    #[inline(always)]
    pub fn inbbase(&self) -> INBBASE_R {
        INBBASE_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Base address register for the input B region"]
    #[inline(always)]
    pub fn inbbase(&mut self) -> INBBASE_W {
        INBBASE_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Base address register for input B region\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [inbbase](index.html) module"]
pub struct INBBASE_SPEC;
impl crate::RegisterSpec for INBBASE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [inbbase::R](R) reader structure"]
impl crate::Readable for INBBASE_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [inbbase::W](W) writer structure"]
impl crate::Writable for INBBASE_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets INBBASE to value 0"]
impl crate::Resettable for INBBASE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
